summaryrefslogtreecommitdiffstats
path: root/framework/source/services
diff options
context:
space:
mode:
authorThomas Arnhold <thomas@arnhold.org>2013-04-15 04:49:39 +0200
committerThomas Arnhold <thomas@arnhold.org>2013-04-15 04:49:39 +0200
commit60fbefc615f8931bf8b952293fc4eb4ac35dafd8 (patch)
tree2a91fcbcb206d60dcc652a336bb9b6813578815e /framework/source/services
parentResolves: #i119567# wmf in PICT assure correct scaling... (diff)
downloadcore-60fbefc615f8931bf8b952293fc4eb4ac35dafd8.tar.gz
core-60fbefc615f8931bf8b952293fc4eb4ac35dafd8.zip
fdo#60724 informations -> information
Change-Id: Ifd34ebfc7fe01b4a470eb072597dd3ec97c97863
Diffstat (limited to 'framework/source/services')
-rw-r--r--framework/source/services/autorecovery.cxx4
-rw-r--r--framework/source/services/desktop.cxx12
-rw-r--r--framework/source/services/frame.cxx14
-rw-r--r--framework/source/services/pathsettings.cxx2
-rw-r--r--framework/source/services/tabwindowservice.cxx2
-rw-r--r--framework/source/services/taskcreatorsrv.cxx2
6 files changed, 18 insertions, 18 deletions
diff --git a/framework/source/services/pathsettings.cxx b/framework/source/services/pathsettings.cxx
index 6f52a62bebc7..1369950ae942 100644
--- a/framework/source/services/pathsettings.cxx
+++ b/framework/source/services/pathsettings.cxx
@@ -112,7 +112,7 @@ DEFINE_INIT_SERVICE ( PathSettings,
/*Attention
I think we don't need any mutex or lock here ... because we are called by our own static method impl_createInstance()
to create a new instance of this class by our own supported service factory.
- see macro DEFINE_XSERVICEINFO_MULTISERVICE and "impl_initService()" for further informations!
+ see macro DEFINE_XSERVICEINFO_MULTISERVICE and "impl_initService()" for further information!
*/
// fill cache
diff --git a/framework/source/services/tabwindowservice.cxx b/framework/source/services/tabwindowservice.cxx
index 2592bcc94445..bbfd98641522 100644
--- a/framework/source/services/tabwindowservice.cxx
+++ b/framework/source/services/tabwindowservice.cxx
@@ -306,7 +306,7 @@ css::uno::Any SAL_CALL TabWindowService::impl_getPropertyValue(const OUString& /
{
/* There is no need to lock any mutex here. Because we share the
solar mutex with our base class. And we said to our base class: "dont release it on calling us" .-)
- see ctor of PropertySetHelper for further informations.
+ see ctor of PropertySetHelper for further information.
*/
css::uno::Any aValue;
diff --git a/framework/source/services/taskcreatorsrv.cxx b/framework/source/services/taskcreatorsrv.cxx
index 52f5ebe60a7d..123106626816 100644
--- a/framework/source/services/taskcreatorsrv.cxx
+++ b/framework/source/services/taskcreatorsrv.cxx
@@ -74,7 +74,7 @@ DEFINE_INIT_SERVICE(
/*Attention
I think we don't need any mutex or lock here ... because we are called by our own static method impl_createInstance()
to create a new instance of this class by our own supported service factory.
- see macro DEFINE_XSERVICEINFO_MULTISERVICE and "impl_initService()" for further informations!
+ see macro DEFINE_XSERVICEINFO_MULTISERVICE and "impl_initService()" for further information!
*/
}
)
diff --git a/framework/source/services/autorecovery.cxx b/framework/source/services/autorecovery.cxx
index 20ffa4585f22..507d9162d491 100644
--- a/framework/source/services/autorecovery.cxx
+++ b/framework/source/services/autorecovery.cxx
@@ -428,7 +428,7 @@ DEFINE_INIT_SERVICE(
/*Attention
I think we don't need any mutex or lock here ... because we are called by our own static method impl_createInstance()
to create a new instance of this class by our own supported service factory.
- see macro DEFINE_XSERVICEINFO_MULTISERVICE and "impl_initService()" for further informations!
+ see macro DEFINE_XSERVICEINFO_MULTISERVICE and "impl_initService()" for further information!
*/
// read configuration to know if autosave/recovery is on/off etcpp...
@@ -2320,7 +2320,7 @@ void AutoRecovery::implts_saveOneDoc(const OUString&
const css::uno::Reference< css::task::XStatusIndicator >& xExternalProgress)
{
// no document? => can occure if we loaded our configuration with files,
// which couldnt be recovered successfully. In such case we have all needed informations
// excepting the real document instance!
// TODO: search right place, where such "dead files" can be removed from the configuration!
@@ -2320,7 +2320,7 @@ void AutoRecovery::implts_saveOneDoc(const OUString&
{
// no document? => can occure if we loaded our configuration with files,
- // which couldnt be recovered successfully. In such case we have all needed informations
+ // which couldnt be recovered successfully. In such case we have all needed information
// excepting the real document instance!
// TODO: search right place, where such "dead files" can be removed from the configuration!
diff --git a/framework/source/services/desktop.cxx b/framework/source/services/desktop.cxx
index b46b5c8fff3f..6e8edbea9b2c 100644
--- a/framework/source/services/desktop.cxx
+++ b/framework/source/services/desktop.cxx
@@ -129,7 +129,7 @@ DEFINE_INIT_SERVICE ( Desktop,
/*Attention
I think we don't need any mutex or lock here ... because we are called by our own static method impl_createInstance()
to create a new instance of this class by our own supported service factory.
- see macro DEFINE_XSERVICEINFO_MULTISERVICE and "impl_initService()" for further informations!
+ see macro DEFINE_XSERVICEINFO_MULTISERVICE and "impl_initService()" for further information!
*/
//-------------------------------------------------------------------------------------------------------------
@@ -208,7 +208,7 @@ Desktop::Desktop( const css::uno::Reference< css::lang::XMultiServiceFactory >&
, ::cppu::OWeakObject ( )
// Init member
#ifdef ENABLE_ASSERTIONS
- , m_bIsTerminated ( sal_False ) // see dispose() for further informations!
+ , m_bIsTerminated ( sal_False ) // see dispose() for further information!
#endif
, m_xFactory ( xFactory )
, m_aChildTaskContainer ( )
@@ -358,7 +358,7 @@ sal_Bool SAL_CALL Desktop::terminate()
{
#ifdef ENABLE_ASSERTIONS
// "Protect" us against dispose before terminate calls!
// see dispose() for further informations.
/* SAFE AREA --------------------------------------------------------------------------------------- */
WriteGuard aWriteLock( m_aLock );
m_bIsTerminated = sal_True;
@@ -1234,7 +1234,7 @@ void SAL_CALL Desktop::dispose()
/*-************************************************************************************************************//**
@interface XComponent
@short add/remove listener for dispose events
- @descr Add an event listener to this object, if you whish to get informations
+ @descr Add an event listener to this object, if you whish to get information
about our dieing!
You must releas ethis listener reference during your own disposing() method.
@@ -1283,7 +1283,7 @@ void SAL_CALL Desktop::removeEventListener( const css::uno::Reference< css::lang
@seealso method loadComponentFromURL()
- @param "aEvent", state event which (hopefully) valid informations
+ @param "aEvent", state event which (hopefully) valid information
@return -
@onerror -
@@ -1618,7 +1618,7 @@ void SAL_CALL Desktop::getFastPropertyValue( css::uno::Any& aValue ,
@seealso class OPropertySetHelper
@param -
- @return structure with property-informations
+ @return structure with property-information
@onerror -
@threadsafe yes
@@ -358,7 +358,7 @@ sal_Bool SAL_CALL Desktop::terminate()
#ifdef ENABLE_ASSERTIONS
// "Protect" us against dispose before terminate calls!
- // see dispose() for further informations.
+ // see dispose() for further information.
/* SAFE AREA --------------------------------------------------------------------------------------- */
WriteGuard aWriteLock( m_aLock );
diff --git a/framework/source/services/frame.cxx b/framework/source/services/frame.cxx
index e651994879fe..46657f92eafd 100644
--- a/framework/source/services/frame.cxx
+++ b/framework/source/services/frame.cxx
@@ -157,7 +157,7 @@ DEFINE_INIT_SERVICE ( Frame,
/*Attention
I think we don't need any mutex or lock here ... because we are called by our own static method impl_createInstance()
to create a new instance of this class by our own supported service factory.
- see macro DEFINE_XSERVICEINFO_MULTISERVICE and "impl_initService()" for further informations!
+ see macro DEFINE_XSERVICEINFO_MULTISERVICE and "impl_initService()" for further information!
*/
css::uno::Reference< css::uno::XInterface > xThis(static_cast< ::cppu::OWeakObject* >(this), css::uno::UNO_QUERY_THROW);
@@ -1084,7 +1084,7 @@ void SAL_CALL Frame::activate() throw( css::uno::RuntimeException )
// Attention: Deactivation of an active path, deactivate the whole path ... from bottom to top!
// But we wish to deactivate founded sibling-tree only.
// [ see deactivate() / step 4) for further informations! ]
xParent->setActiveFrame( xThis );
@@ -2003,7 +2003,7 @@ void SAL_CALL Frame::removeEventListener( const css::uno::Reference< css::lang::
/*-****************************************************************************************************//**
@short create new status indicator
- @descr Use returned status indicator to show progresses and some text informations.
+ @descr Use returned status indicator to show progresses and some text information.
All created objects share the same dialog! Only the last one can show his information.
@seealso class StatusIndicatorFactory
@@ -2112,7 +2112,7 @@ css::uno::Sequence< css::uno::Reference< css::frame::XDispatch > > SAL_CALL Fram
/*-****************************************************************************************************//**
@short register/unregister interceptor for dispatch calls
@descr If you whish to handle some dispatches by himself ... you should be
- an interceptor for it. Please see class OInterceptionHelper for further informations.
+ an interceptor for it. Please see class OInterceptionHelper for further information.
@seealso class OInterceptionHelper
@@ -2544,7 +2544,7 @@ sal_Int16 SAL_CALL Frame::resetActionLocks() throw( css::uno::RuntimeException )
// Attention:
// external lock count is 0 here every time ... but if
// member m_bSelfClose is set to true too .... we call our own close()/dispose().
// See close() for further informations
implts_checkSuicide();
return nCurrentLocks;
@@ -2599,7 +2599,7 @@ void SAL_CALL Frame::impl_setPropertyValue(const OUString& /*sProperty*/,
{
/* There is no need to lock any mutex here. Because we share the
solar mutex with our base class. And we said to our base class: "dont release it on calling us" .-)
- see ctor of PropertySetHelper for further informations.
+ see ctor of PropertySetHelper for further information.
*/
/* Attention: You can use nHandle only, if you are sure that all supported
@@ -2659,7 +2659,7 @@ css::uno::Any SAL_CALL Frame::impl_getPropertyValue(const OUString& /*sProperty*
{
/* There is no need to lock any mutex here. Because we share the
solar mutex with our base class. And we said to our base class: "dont release it on calling us" .-)
- see ctor of PropertySetHelper for further informations.
+ see ctor of PropertySetHelper for further information.
*/
/* Attention: You can use nHandle only, if you are sure that all supported
@@ -1084,7 +1084,7 @@ void SAL_CALL Frame::activate() throw( css::uno::RuntimeException )
// Attention: Deactivation of an active path, deactivate the whole path ... from bottom to top!
// But we wish to deactivate founded sibling-tree only.
- // [ see deactivate() / step 4) for further informations! ]
+ // [ see deactivate() / step 4) for further information! ]
xParent->setActiveFrame( xThis );
@@ -2544,7 +2544,7 @@ sal_Int16 SAL_CALL Frame::resetActionLocks() throw( css::uno::RuntimeException )
// external lock count is 0 here every time ... but if
// member m_bSelfClose is set to true too .... we call our own close()/dispose().
- // See close() for further informations
+ // See close() for further information
implts_checkSuicide();
return nCurrentLocks;